Installation |pypi_version| |python_versions| |pypi_license|
============================================================

Easiest
~~~~~~~
Download the latest stable code from `PyPI <https://pypi.python.org/pypi/pykeen>`_ with:

.. code-block:: python

   python3 -m pip install pykeen

Get the Latest
~~~~~~~~~~~~~~~
Download the most recent code from `GitHub <https://github.com/SmartDataAnalytics/PyKEEN>`_ with:

.. code-block:: python

   python3 -m pip install git+https://github.com/SmartDataAnalytics/PyKEEN.git@develop

.. |python_versions| image:: https://img.shields.io/pypi/pyversions/pykeen.svg
    :alt: Stable Supported Python Versions
.. |pypi_version| image:: https://img.shields.io/pypi/v/pykeen.svg
    :alt: Current version on PyPI
.. |pypi_license| image:: https://img.shields.io/pypi/l/pykeen.svg
    :alt: MIT License
